# Kik Desktop #
Kik desktop client written in PyQt5 based on [Kik Bot API](https://github.com/tomer8007/kik-bot-api-unofficial)

WARNING: Logging in causes a logout on any currently logged in client, messages will be lost. 

## Features
- Store login, messages
- Send/receive messages

## Backlog
- Retrieve received messaged on relogin
- All Kik server communication beyond send/receiving messages
- Register account
- Media support
